stravalib.util.limiter.SleepingRateLimitRule
============================================

.. currentmodule:: stravalib.util.limiter

.. autoclass:: SleepingRateLimitRule


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~SleepingRateLimitRule.__init__
